==> pytablewriter-0.21.0.tar.gz: pytablewriter-0.21.0/pytablewriter/writer/sourcecode/_pandas.py <==
# encoding: utf-8

"""
.. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
"""

from __future__ import absolute_import
from __future__ import unicode_literals

from mbstrdecoder import MultiByteStrDecoder
import typepy

from ..._error import EmptyTableNameError
from ..._function import (
    quote_datetime_formatter,
    dateutil_datetime_formatter
)
from ._python import PythonCodeTableWriter


class PandasDataFrameWriter(PythonCodeTableWriter):
    """
    A writer class for Pandas DataFrame format.

    .. py:attribute:: import_pandas_as

        Specify ``pandas`` module import name. Defaults to ``"pd"``.

    .. py:attribute:: import_numpy_as

        Specify ``numpy`` module import name. Defaults to ``"np"``.

    .. py:method:: write_table

        |write_table| with Pandas DataFrame format.
        The tabular data will be written as a ``pandas.DataFrame`` class
        instance definition.

        :raises pytablewriter.EmptyTableNameError:
            If the |table_name| is empty.
        :raises pytablewriter.EmptyHeaderError: If the |header_list| is empty.
        :Examples:
            :ref:`example-pandas-dataframe-writer`

        .. note::

            Values in the tabular data which described below will be converted
            when writing:

            - |None|: written as ``None``
            - |inf|: written as ``numpy.inf``
            - |nan|: written as ``numpy.nan``
            - |datetime| instances determined by |is_datetime_instance_formatting| attribute:
                - |True|: written as `dateutil.parser <https://dateutil.readthedocs.io/en/stable/parser.html>`__
                - |False|: written as |str|

            .. seealso::

                :ref:`example-type-hint-python`
    """

    @property
    def format_name(self):
        return "pandas"

    def __init__(self):
        super(PandasDataFrameWriter, self).__init__()

        self.table_name = ""
        self.import_pandas_as = "pd"
        self.import_numpy_as = "np"
        self.is_write_header = False
        self._dp_extractor.type_value_mapping[typepy.Typecode.INFINITY] = (
            "{:s}.inf".format(self.import_numpy_as))
        self._dp_extractor.type_value_mapping[typepy.Typecode.NAN] = (
            "{:s}.nan".format(self.import_numpy_as))

    def _get_opening_row_item_list(self):
        return ["{} = {}.DataFrame([".format(
            self.variable_name, self.import_pandas_as)]

    def _get_closing_row_item_list(self):
        return "], columns=[{}])".format(", ".join([
            '"{}"'.format(MultiByteStrDecoder(header).unicode_str)
            for header in self.header_list
        ]))

    def _verify_property(self):
        super(PandasDataFrameWriter, self)._verify_property()

        if typepy.is_null_string(self.table_name):
            raise EmptyTableNameError(
                "table_name must be a string of one or more characters")

    def _verify_header(self):
        self._validate_empty_header()

==> pytablewriter-0.21.1.tar.gz: pytablewriter-0.21.1/pytablewriter/writer/sourcecode/_pandas.py <==
# encoding: utf-8

"""
.. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
"""

from __future__ import absolute_import
from __future__ import unicode_literals

from mbstrdecoder import MultiByteStrDecoder
import typepy

from ..._error import EmptyTableNameError
from ..._function import (
    quote_datetime_formatter,
    dateutil_datetime_formatter
)
from ._numpy import NumpyTableWriter


class PandasDataFrameWriter(NumpyTableWriter):
    """
    A writer class for Pandas DataFrame format.

    .. py:attribute:: import_pandas_as

        Specify ``pandas`` module import name. Defaults to ``"pd"``.

    .. py:attribute:: import_numpy_as

        Specify ``numpy`` module import name. Defaults to ``"np"``.

    .. py:method:: write_table

        |write_table| with Pandas DataFrame format.
        The tabular data are written as a ``pandas.DataFrame`` class
        instance definition.

        :raises pytablewriter.EmptyTableNameError:
            If the |table_name| is empty.
        :raises pytablewriter.EmptyHeaderError: If the |header_list| is empty.
        :Examples:
            :ref:`example-pandas-dataframe-writer`

        .. note::
            Values in the tabular data which described below will be converted
            when writing:

            - |None|: written as ``None``
            - |inf|: written as ``numpy.inf``
            - |nan|: written as ``numpy.nan``
            - |datetime| instances determined by |is_datetime_instance_formatting| attribute:
                - |True|: written as `dateutil.parser <https://dateutil.readthedocs.io/en/stable/parser.html>`__
                - |False|: written as |str|

            .. seealso::
                :ref:`example-type-hint-python`
    """

    @property
    def format_name(self):
        return "pandas"

    def __init__(self):
        super(PandasDataFrameWriter, self).__init__()

        self.table_name = ""
        self.import_pandas_as = "pd"
        self.is_write_header = False

    def _get_opening_row_item_list(self):
        return ["{} = {}.DataFrame([".format(
            self.variable_name, self.import_pandas_as)]

    def _get_closing_row_item_list(self):
        return "], columns=[{}])".format(", ".join([
            '"{}"'.format(MultiByteStrDecoder(header).unicode_str)
            for header in self.header_list
        ]))

    def _verify_property(self):
        super(PandasDataFrameWriter, self)._verify_property()

        if typepy.is_null_string(self.table_name):
            raise EmptyTableNameError(
                "table_name must be a string of one or more characters")

    def _verify_header(self):
        self._validate_empty_header()
